# Sentry-Ones

`Sentry`的`ONES`issus单自动创建插件

## 安装

```bash
$ pip install sentry-ones
```

## 使用

注意：python版本2.7

在`项目`的所有集成页面找到`ones`插件，启用，并填写相关必填项

![plugin](https://github.com/wbslf/sentry-ones/blob/main/docs/images/1723800780879.png)

在插件上使用`Test Plugin`进行测试，当配置好相关必填信息后，在自动创建ONES单子

![plugin](https://github.com/wbslf/sentry-ones/blob/main/docs/images/1723800915656.jpg) -->


